@@ -193,7 +193,22 @@ function gallery(Graph){
         .data(itemsFiltered ? itemsFiltered : nodes)
         .column(options.nodeLabel)
         .updateSelection(displayGraph)
-        .updateFilter(searchFunction));
+        .updateFilter(function(){
+          if(selectedNames().length){
+            searchFunction();
+          }else{
+            if(!galleryBox.select(".topbar-box > .multi-search > .search-box.noresults").size()){
+              var searchbox = galleryBox.select(".topbar-box > .multi-search > .search-box");
+              var noresults = searchbox.classed("noresults",true)
+                .append("p").attr("class","noresults")
+                  .text(texts.noresults);
+              setTimeout(function(){
+                searchbox.classed("noresults",false)
+                noresults.remove();
+              }, 5000);
+            }
+          }
+        }));
 
   // count elements
   topBar.addBox(elementsCountInst);
@@ -495,6 +510,14 @@ function gallery(Graph){
             d3.select(this.parentNode.parentNode).style("width",(currentGridHeight*this.ratio)+"px");
           } : null)
           .attr("src",function(n){ return n[options.imageItems]; });
+      if(options.imageCopy){
+        imgWrapper.append("span")
+            .attr("class","copyright")
+            .attr("title",function(n){
+              return n[options.imageCopy];
+            })
+            .html("&copy;")
+      }
     }
 
     itemsEnter.append("span")
